@@ -10,6 +10,7 @@ our @EXPORT_OK = qw(
   MAX_ITERATION_WAIT_TIMEOUT
   ITERATION_WAIT_TIMEOUT
   DOCUMENT_DISASSEMBLING_SUCCESS_STATUS
+  PATH_SEPARATOR
 );
 
 use constant COMPLETE                              => 'completed';
@@ -17,5 +18,6 @@ use constant EXPORT_ZIP_FILES_COUNT                => 10;
 use constant MAX_ITERATION_WAIT_TIMEOUT            => 300;
 use constant ITERATION_WAIT_TIMEOUT                => 1;
 use constant DOCUMENT_DISASSEMBLING_SUCCESS_STATUS => 'success';
+use constant PATH_SEPARATOR => '/';
 
 1;
\ No newline at end of file
