@@ -18,6 +18,8 @@ our @EXPORT = qw(
   get_language_from_ts_filepath
   get_ts_file_key
   get_document_key
+  get_file_id
+  get_file_name
   format_error_message
   get_file_path
   are_po_files_empty
@@ -49,27 +51,57 @@ sub get_language_from_ts_filepath {
     return shift @path_items;
 }
 
-
 sub get_ts_file_key {
-    my ($project_workdir, $path) = @_;
+    my ($project_workdir, $path, $should_extract_file_id) = @_;
 
     my @path_items = _get_path_items($project_workdir, $path);
 
     my $language = shift @path_items;
     my $filepath = join(PATH_SEPARATOR, @path_items);
+    
+    if ( $should_extract_file_id ) {
+        my ( $volume, $directories, $filename ) = splitpath( $filepath );
+        if ($filename =~ /^(.+)---([^\.].+?)$/) {
+            $filepath = $volume.$directories.$2;
+        }
+    }
 
     return "$filepath ($language)";
 }
 
-
 sub get_document_key {
-    my ( $name, $target_language ) = @_;
-
-    my $key = $name;
+    my ( $full_path, $target_language, $should_extract_file_id ) = @_;
+    my $key = $full_path;
     $key =~ s/_($target_language)$//i;
+
+    if ( $should_extract_file_id ) {
+        my ( $volume, $directories, $filename ) = splitpath( $key );
+        if ($filename =~ /^(.+)---([^\.].+?)$/) {
+            $key = $volume.$directories.$2;
+        }
+    }
+
     return $key . ' (' . $target_language . ')';
 }
 
+sub get_file_id {
+    my ( $filepath ) = @_;
+    
+    my ($volume, $directories, $name) = splitpath($filepath);
+
+    if ($name =~ /^(.+)---([^\.].+?)(\..+)?$/) {
+        return $2;
+    }
+    return undef;
+}
+
+sub get_file_name {
+    my ( $filepath, $filetype, $target_language ) = @_;
+
+    my ( $filename, $dirs, $ext ) = fileparse( $filepath, $filetype );
+
+    return $filename . '_' . $target_language;
+}
 
 sub prepare_document_name {
     my ( $project_workdir, $path, $filetype, $target_language ) = @_;
